==> org.opennms.features.telemetry.protocols.sflow.parser-25.0.0-20190307.220803-5-sources.jar: org/opennms/netmgt/telemetry/protocols/sflow/parser/proto/flows/Mib2UdpGroup.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2018 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2018 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.telemetry.protocols.sflow.parser.proto.flows;

import java.nio.ByteBuffer;

import org.bson.BsonWriter;
import org.opennms.netmgt.telemetry.common.utils.BufferUtils;
import org.opennms.netmgt.telemetry.protocols.sflow.parser.InvalidPacketException;

import com.google.common.base.MoreObjects;

// struct mib2_udp_group {
//   unsigned int udpInDatagrams;
//   unsigned int udpNoPorts;
//   unsigned int udpInErrors;
//   unsigned int udpOutDatagrams;
//   unsigned int udpRcvbufErrors;
//   unsigned int udpSndbufErrors;
//   unsigned int udpInCsumErrors;
// };

public class Mib2UdpGroup implements CounterData {
    public final long udpInDatagrams;
    public final long udpNoPorts;
    public final long udpInErrors;
    public final long udpOutDatagrams;
    public final long udpRcvbufErrors;
    public final long udpSndbufErrors;
    public final long udpInCsumErrors;

    public Mib2UdpGroup(final ByteBuffer buffer) throws InvalidPacketException {
        this.udpInDatagrams = BufferUtils.uint32(buffer);
        this.udpNoPorts = BufferUtils.uint32(buffer);
        this.udpInErrors = BufferUtils.uint32(buffer);
        this.udpOutDatagrams = BufferUtils.uint32(buffer);
        this.udpRcvbufErrors = BufferUtils.uint32(buffer);
        this.udpSndbufErrors = BufferUtils.uint32(buffer);
        this.udpInCsumErrors = BufferUtils.uint32(buffer);
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
                .add("udpInDatagrams", this.udpInDatagrams)
                .add("udpNoPorts", this.udpNoPorts)
                .add("udpInErrors", this.udpInErrors)
                .add("udpOutDatagrams", this.udpOutDatagrams)
                .add("udpRcvbufErrors", this.udpRcvbufErrors)
                .add("udpSndbufErrors", this.udpSndbufErrors)
                .add("udpInCsumErrors", this.udpInCsumErrors)
                .toString();
    }

    @Override
    public void writeBson(final BsonWriter bsonWriter) {
        bsonWriter.writeStartDocument();
        bsonWriter.writeInt64("udpInDatagrams", this.udpInDatagrams);
        bsonWriter.writeInt64("udpNoPorts", this.udpNoPorts);
        bsonWriter.writeInt64("udpInErrors", this.udpInErrors);
        bsonWriter.writeInt64("udpOutDatagrams", this.udpOutDatagrams);
        bsonWriter.writeInt64("udpRcvbufErrors", this.udpRcvbufErrors);
        bsonWriter.writeInt64("udpSndbufErrors", this.udpSndbufErrors);
        bsonWriter.writeInt64("udpInCsumErrors", this.udpInCsumErrors);
        bsonWriter.writeEndDocument();
    }

}

==> org.opennms.features.telemetry.protocols.sflow.parser-25.0.0-20191026.205450-127-sources.jar: org/opennms/netmgt/telemetry/protocols/sflow/parser/proto/flows/Mib2UdpGroup.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2018 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2018 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.telemetry.protocols.sflow.parser.proto.flows;

import java.nio.ByteBuffer;

import org.bson.BsonWriter;
import org.opennms.netmgt.telemetry.common.utils.BufferUtils;
import org.opennms.netmgt.telemetry.protocols.sflow.parser.SampleDatagramEnrichment;
import org.opennms.netmgt.telemetry.protocols.sflow.parser.InvalidPacketException;

import com.google.common.base.MoreObjects;

// struct mib2_udp_group {
//   unsigned int udpInDatagrams;
//   unsigned int udpNoPorts;
//   unsigned int udpInErrors;
//   unsigned int udpOutDatagrams;
//   unsigned int udpRcvbufErrors;
//   unsigned int udpSndbufErrors;
//   unsigned int udpInCsumErrors;
// };

public class Mib2UdpGroup implements CounterData {
    public final long udpInDatagrams;
    public final long udpNoPorts;
    public final long udpInErrors;
    public final long udpOutDatagrams;
    public final long udpRcvbufErrors;
    public final long udpSndbufErrors;
    public final long udpInCsumErrors;

    public Mib2UdpGroup(final ByteBuffer buffer) throws InvalidPacketException {
        this.udpInDatagrams = BufferUtils.uint32(buffer);
        this.udpNoPorts = BufferUtils.uint32(buffer);
        this.udpInErrors = BufferUtils.uint32(buffer);
        this.udpOutDatagrams = BufferUtils.uint32(buffer);
        this.udpRcvbufErrors = BufferUtils.uint32(buffer);
        this.udpSndbufErrors = BufferUtils.uint32(buffer);
        this.udpInCsumErrors = BufferUtils.uint32(buffer);
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
                .add("udpInDatagrams", this.udpInDatagrams)
                .add("udpNoPorts", this.udpNoPorts)
                .add("udpInErrors", this.udpInErrors)
                .add("udpOutDatagrams", this.udpOutDatagrams)
                .add("udpRcvbufErrors", this.udpRcvbufErrors)
                .add("udpSndbufErrors", this.udpSndbufErrors)
                .add("udpInCsumErrors", this.udpInCsumErrors)
                .toString();
    }

    @Override
    public void writeBson(final BsonWriter bsonWriter, final SampleDatagramEnrichment enr) {
        bsonWriter.writeStartDocument();
        bsonWriter.writeInt64("udpInDatagrams", this.udpInDatagrams);
        bsonWriter.writeInt64("udpNoPorts", this.udpNoPorts);
        bsonWriter.writeInt64("udpInErrors", this.udpInErrors);
        bsonWriter.writeInt64("udpOutDatagrams", this.udpOutDatagrams);
        bsonWriter.writeInt64("udpRcvbufErrors", this.udpRcvbufErrors);
        bsonWriter.writeInt64("udpSndbufErrors", this.udpSndbufErrors);
        bsonWriter.writeInt64("udpInCsumErrors", this.udpInCsumErrors);
        bsonWriter.writeEndDocument();
    }

}
